(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     63259,       1223]
NotebookOptionsPosition[     62856,       1205]
NotebookOutlinePosition[     63200,       1220]
CellTagsIndexPosition[     63157,       1217]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Jim Schwiegerling Relating wavefront error, apodization, and the optical \
transfer function: Reply\n\nThese are equations 21 and 22 from my 2014 paper \
\[OpenCurlyDoubleQuote]Relating wavefront error, apodization, and the optical \
transfer function: on-axis case,\[CloseCurlyDoubleQuote] J. Opt. Soc. Am. A \
31, 2476-2483 (2014). Calculate all the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "k"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " coefficients and then the basis functions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["G", "\[ScriptL]\[ScriptL]0"], "(", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "\[Beta]"}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ".  I get about 1-15 msec to create the function depending on the value of ",
 StyleBox["l",
  FontSlant->"Italic"],
 ".  The other thing to be careful of is loss of precicison as \[Beta] \
approaches 2.  This can be handled by increasing the working precision.  \
SImilar techniques can be used to calculate the cases \[ScriptL] \[NotEqual] \
m."
}], "Text",
 CellChangeTimes->{{3.67440573464545*^9, 3.674405804447542*^9}, {
  3.676311061987425*^9, 3.67631106358937*^9}, {3.6763112093887024`*^9, 
  3.676311241325466*^9}, {3.6763112935455604`*^9, 3.676311495657138*^9}, {
  3.67631160796106*^9, 3.6763116164812393`*^9}, {3.6763116554161572`*^9, 
  3.6763116772725863`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"dk", "[", 
    RowBox[{"l_", ",", "k_", ",", "dlist_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"2", "*", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{
        RowBox[{"2", "k"}], "+", "1"}], "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", "*", "l", "*", 
        RowBox[{"4", "^", "k"}], "*", 
        RowBox[{
         RowBox[{"Gamma", "[", 
          RowBox[{"k", "+", "1"}], "]"}], "^", "2"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "k"}], "+", "1"}], ")"}]}], ")"}]}]}], "-", 
    RowBox[{"4", "*", 
     RowBox[{"Pochhammer", "[", 
      RowBox[{
       RowBox[{"l", "+", 
        RowBox[{"1", "/", "2"}]}], ",", "k"}], "]"}], "*", 
     RowBox[{"Pochhammer", "[", 
      RowBox[{
       RowBox[{"1", "/", "2"}], ",", "k"}], "]"}], "*", 
     RowBox[{
      RowBox[{"Pochhammer", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "l"}], "+", 
         RowBox[{"1", "/", "2"}]}], ",", "k"}], "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", "*", 
        RowBox[{"Gamma", "[", 
         RowBox[{"k", "+", "1"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Pochhammer", "[", 
          RowBox[{
           RowBox[{"3", "/", "2"}], ",", "k"}], "]"}], "^", "2"}]}], 
       ")"}]}]}], "-", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"dlist", "[", 
        RowBox[{"[", 
         RowBox[{"kp", "+", "1"}], "]"}], "]"}], "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"k", "-", "kp"}], ")"}]}], "*", 
       RowBox[{"Binomial", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", 
         RowBox[{"k", "-", "kp"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"kp", ",", "0", ",", 
        RowBox[{"k", "-", "1"}]}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GLL0", "[", 
    RowBox[{"l_", ",", "\[Beta]_", ",", "dlist_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"dlist", "[", 
         RowBox[{"[", 
          RowBox[{"k", "+", "1"}], "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Beta]", "/", "2"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"2", "*", "k"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", 
         RowBox[{"l", "-", "1"}]}], "}"}]}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{"\[Beta]", "/", "2"}], ")"}], "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Beta]", "/", "2"}], ")"}], "^", "2"}]}], "]"}]}], "+", 
    RowBox[{"2", "*", 
     RowBox[{
      RowBox[{"ArcCos", "[", 
       RowBox[{"\[Beta]", "/", "2"}], "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", "*", "l"}], ")"}]}]}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"l", "=", "50"}], ";", "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"l", " ", "=", " ", 
    RowBox[{
    "50", " ", "is", " ", "the", " ", "example", " ", "basis", " ", 
     "function", " ", "given", " ", "in", " ", "Figure", " ", "1"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"dlist", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "/", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", "*", "l"}], ")"}]}], "-", 
     RowBox[{"4", "/", "\[Pi]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"k", "=", "1"}], ",", 
    RowBox[{"k", "\[LessEqual]", 
     RowBox[{"l", "-", "1"}]}], ",", 
    RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"AppendTo", "[", 
      RowBox[{"dlist", ",", 
       RowBox[{"dk", "[", 
        RowBox[{"l", ",", "k", ",", "dlist"}], "]"}]}], "]"}], ";"}]}], 
   "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GLL0", "[", 
  RowBox[{"l", ",", "\[Beta]", ",", "dlist"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"GLL0", "[", 
    RowBox[{"l", ",", "\[Beta]", ",", "dlist"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Beta]", ",", "0", ",", "2"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", 
   RowBox[{"WorkingPrecision", "\[Rule]", "50"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.6743998828782024`*^9, 3.674400009126052*^9}, {
   3.6744001564632316`*^9, 3.6744001688104897`*^9}, 3.6744003553161583`*^9, {
   3.6744003867922688`*^9, 3.6744003959502316`*^9}, {3.67440045313736*^9, 
   3.674400502379673*^9}, {3.6744005647907457`*^9, 3.674400575073617*^9}, {
   3.674400776738844*^9, 3.6744008781116695`*^9}, {3.6744009717472687`*^9, 
   3.6744009980804787`*^9}, {3.67440104746638*^9, 3.6744011052254233`*^9}, {
   3.6744011464339204`*^9, 3.674401179934787*^9}, {3.674401601702143*^9, 
   3.6744016383414288`*^9}, {3.6744017223291636`*^9, 3.674401726921562*^9}, {
   3.674402035802574*^9, 3.6744020455824757`*^9}, {3.6744023501127872`*^9, 
   3.674402363793598*^9}, {3.674402424375592*^9, 3.674402513841807*^9}, {
   3.6744025706263742`*^9, 3.674402613276394*^9}, {3.674402669124086*^9, 
   3.6744027553518915`*^9}, {3.6744028818155584`*^9, 
   3.6744028830604973`*^9}, {3.674403985776204*^9, 3.6744041082136073`*^9}, {
   3.6744042776996393`*^9, 3.6744043070303335`*^9}, {3.674404447477711*^9, 
   3.6744044643566976`*^9}, {3.674404577502096*^9, 3.6744045812202187`*^9}, {
   3.6744058462861977`*^9, 3.674405847187477*^9}, {3.6763111113651695`*^9, 
   3.676311114103387*^9}, {3.6763115117697544`*^9, 3.6763115354795046`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "\[Beta]", " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     FractionBox[
      SuperscriptBox["\[Beta]", "2"], "4"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["99", 
       RowBox[{"25", " ", "\[Pi]"}]]}], "+", 
     FractionBox[
      RowBox[{"83251", " ", 
       SuperscriptBox["\[Beta]", "2"]}], 
      RowBox[{"150", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"15583372", " ", 
       SuperscriptBox["\[Beta]", "4"]}], 
      RowBox[{"375", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"220019502", " ", 
       SuperscriptBox["\[Beta]", "6"]}], 
      RowBox[{"125", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"53124681296", " ", 
       SuperscriptBox["\[Beta]", "8"]}], 
      RowBox[{"1125", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"2151132557822", " ", 
       SuperscriptBox["\[Beta]", "10"]}], 
      RowBox[{"2475", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"124557391617103", " ", 
       SuperscriptBox["\[Beta]", "12"]}], 
      RowBox[{"10725", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"37790367010426919", " ", 
       SuperscriptBox["\[Beta]", "14"]}], 
      RowBox[{"321750", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"2537842422007430762", " ", 
       SuperscriptBox["\[Beta]", "16"]}], 
      RowBox[{"2734875", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"33899594245802340944", " ", 
       SuperscriptBox["\[Beta]", "18"]}], 
      RowBox[{"5773625", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"210273970907556823871", " ", 
       SuperscriptBox["\[Beta]", "20"]}], 
      RowBox[{"6928350", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"3773978654965510032529", " ", 
       SuperscriptBox["\[Beta]", "22"]}], 
      RowBox[{"28973100", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"56795425924994231596907", " ", 
       SuperscriptBox["\[Beta]", "24"]}], 
      RowBox[{"120721250", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"725201008225200422164793", " ", 
       SuperscriptBox["\[Beta]", "26"]}], 
      RowBox[{"501457500", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"55547148794405379344840299", " ", 
       SuperscriptBox["\[Beta]", "28"]}], 
      RowBox[{"14542267500", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"525303226903380291808883861", " ", 
       SuperscriptBox["\[Beta]", "30"]}], 
      RowBox[{"60108039000", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"4324677968109333782868406339", " ", 
       SuperscriptBox["\[Beta]", "32"]}], 
      RowBox[{"247945660875", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"4455593402214872800195818383", " ", 
       SuperscriptBox["\[Beta]", "34"]}], 
      RowBox[{"145850388750", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"28300801774867969163468196667", " ", 
       SuperscriptBox["\[Beta]", "36"]}], 
      RowBox[{"599607153750", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"159056855235049640072927454533", " ", 
       SuperscriptBox["\[Beta]", "38"]}], 
      RowBox[{"2461545157500", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"794155168212801830900167410907", " ", 
       SuperscriptBox["\[Beta]", "40"]}], 
      RowBox[{"10092335145750", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"24742834876125099136815397828451", " ", 
       SuperscriptBox["\[Beta]", "42"]}], 
      RowBox[{"289313607511500", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"98460815647274000654288380058989", " ", 
       SuperscriptBox["\[Beta]", "44"]}], 
      RowBox[{"1183555667092500", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"351173612612179883820244959083411", " ", 
       SuperscriptBox["\[Beta]", "46"]}], 
      RowBox[{"4837140552465000", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"1124913297198011067933789239902189", " ", 
       SuperscriptBox["\[Beta]", "48"]}], 
      RowBox[{"19751657255898750", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"3241746105724803031554194548791587", " ", 
       SuperscriptBox["\[Beta]", "50"]}], 
      RowBox[{"80586761604066900", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"158777272758780034488606588323921", " ", 
       SuperscriptBox["\[Beta]", "52"]}], 
      RowBox[{"6198981661851300", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"33784119787407051893709085389549", " ", 
       SuperscriptBox["\[Beta]", "54"]}], 
      RowBox[{"2295919134019000", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"71336924697712116564837185372851", " ", 
       SuperscriptBox["\[Beta]", "56"]}], 
      RowBox[{"9347670759934500", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"2303818727415440682467104553911", " ", 
       SuperscriptBox["\[Beta]", "58"]}], 
      RowBox[{"644666948961000", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"64927816250314381501443172269", " ", 
       SuperscriptBox["\[Beta]", "60"]}], 
      RowBox[{"42977796597400", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"100657924246840116753768104531", " ", 
       SuperscriptBox["\[Beta]", "62"]}], 
      RowBox[{"174683947460400", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"140596399604647507675035260089", " ", 
       SuperscriptBox["\[Beta]", "64"]}], 
      RowBox[{"709653536557875", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"29009643045574138510708971913", " ", 
       SuperscriptBox["\[Beta]", "66"]}], 
      RowBox[{"473102357705250", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"16371637914897171838355018506", " ", 
       SuperscriptBox["\[Beta]", "68"]}], 
      RowBox[{"960119490637125", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"116595341770233328801194437", " ", 
       SuperscriptBox["\[Beta]", "70"]}], 
      RowBox[{"27431985446775", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"2885744421013157262603362", " ", 
       SuperscriptBox["\[Beta]", "72"]}], 
      RowBox[{"3047998382975", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"1160008464888211748210333", " ", 
       SuperscriptBox["\[Beta]", "74"]}], 
      RowBox[{"6178375100625", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"826115818245767698727692", " ", 
       SuperscriptBox["\[Beta]", "76"]}], 
      RowBox[{"25038678039375", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"3279543983501649874126", " ", 
       SuperscriptBox["\[Beta]", "78"]}], 
      RowBox[{"642017385625", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"799480764064721969264", " ", 
       SuperscriptBox["\[Beta]", "80"]}], 
      RowBox[{"1155631294125", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"2289472885720835671", " ", 
       SuperscriptBox["\[Beta]", "82"]}], 
      RowBox[{"28186129125", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"109715356588338989", " ", 
       SuperscriptBox["\[Beta]", "84"]}], 
      RowBox[{"13421966250", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"1301144686762559", " ", 
       SuperscriptBox["\[Beta]", "86"]}], 
      RowBox[{"1872832500", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"4162468742069", " ", 
       SuperscriptBox["\[Beta]", "88"]}], 
      RowBox[{"85128750", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"73440768507", " ", 
       SuperscriptBox["\[Beta]", "90"]}], 
      RowBox[{"26484500", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"420592853", " ", 
       SuperscriptBox["\[Beta]", "92"]}], 
      RowBox[{"3454500", " ", "\[Pi]"}]], "+", 
     FractionBox[
      RowBox[{"2854153", " ", 
       SuperscriptBox["\[Beta]", "94"]}], 
      RowBox[{"735000", " ", "\[Pi]"}]], "-", 
     FractionBox[
      RowBox[{"2451", " ", 
       SuperscriptBox["\[Beta]", "96"]}], 
      RowBox[{"30625", " ", "\[Pi]"}]], "+", 
     FractionBox[
      SuperscriptBox["\[Beta]", "98"], 
      RowBox[{"1250", " ", "\[Pi]"}]]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{"ArcCos", "[", 
    FractionBox["\[Beta]", "2"], "]"}], 
   RowBox[{"25", " ", "\[Pi]"}]]}]], "Output",
 CellChangeTimes->{3.6763111730696306`*^9, 3.6763115604560833`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwUV3c8198XFhWRCiUie++9eeyQkK2sIhRaijQkSUWEJC1KmsYXlcq6lFX2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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 2}, {-0.0035778352616108295`, 0.019999974015519496`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6763111730696306`*^9, 3.6763115612954173`*^9}]
}, Open  ]]
},
WindowSize->{832, 424},
WindowMargins->{{152, Automatic}, {Automatic, 80}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 1410, 30, 144, "Text"],
Cell[CellGroupData[{
Cell[1993, 54, 5657, 151, 332, "Input"],
Cell[7653, 207, 8273, 212, 883, "Output"],
Cell[15929, 421, 46911, 781, 224, "Output"]
}, Open  ]]
}
]
*)

